.swipe-container {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 1fr;
}

.swipe-container .outer {
  grid-column: 1;
  grid-row: 1;
}

.swipe-container .slider {
  grid-row: 1;
  grid-column: 1;
  z-index: 1;
  height: 100%;
  cursor: move;
}

.swipe-container .inner {
  width: 100%;
  height: 100%;
}
